betty.project.extension.wikipedia.config module - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.project.extension.wikipedia.config module

Provide configuration for the Wikipedia extension.

class betty.project.extension.wikipedia.config.WikipediaConfiguration

  Bases: `Configuration`

  Provides configuration for the `betty.project.extension.wikipedia.Wikipedia` extension.

  __init__()
  dump() → MutableMapping[str, bool | int | float | str | None | MutableSequence[bool | int | float | str | None | MutableSequence[Dump] | MutableMapping[str, Dump]] | MutableMapping[str, bool | int | float | str | None | MutableSequence[Dump] | MutableMapping[str, Dump]]]

    Produce a serialized data dump of `self`.

  load(dump: bool | int | float | str | None | MutableSequence[bool | int | float | str | None | MutableSequence[Dump] | MutableMapping[str, Dump]] | MutableMapping[str, bool | int | float | str | None | MutableSequence[Dump] | MutableMapping[str, Dump]]) → None

    Load a serialized data dump into `self`.

    Raises:

      betty.assertion.error.AssertionFailed – Raised if the dump is invalid.

  property populate_images: bool

    Whether to populate entities with Wikimedia images after loading ancestries.